@@ -19,13 +19,12 @@ func (o *apiKeyShowItemOutput) toJSON()  { outputJSON(o) }
 func (o *apiKeyShowItemOutput) toText()  { outputText(o) }
 func (o *apiKeyShowItemOutput) toTable() { outputTable(o) }
 
-// apiKeyShowCmd represents the API key showing command
 var apiKeyShowCmd = &cobra.Command{
-	Use:   "show <key | name>",
+	Use:   "show KEY|NAME",
 	Short: "Show API key",
 	Long: fmt.Sprintf(`This command shows an API key details.
 
-	Supported output template annotations: %s`,
+Supported output template annotations: %s`,
 		strings.Join(outputterTemplateAnnotations(&apiKeyShowItemOutput{}), ", ")),
 	Aliases: gShowAlias,
 	RunE: func(cmd *cobra.Command, args []string) error {
