@@ -4,12 +4,15 @@ import (
 	"github.com/spf13/cobra"
 )
 
-// labCmd represents the lab command
 var labCmd = &cobra.Command{
 	Use:   "lab",
 	Short: "Experimental commands",
 	Long: `These commands provide work-in-progress functionalities that may or
-may not be promoted to production someday. Caution: wet paint.`,
+may not be promoted to production someday.
+
+/!\ IMPORTANT: Exoscale provides no guarantees regarding the stability of the
+commands provided in this section, and their syntax can change without prior
+notice.`,
 }
 
 func init() {
