@@ -8,10 +8,9 @@ import (
 	"github.com/spf13/cobra"
 )
 
-// startCmd represents the start command
 var vmStartCmd = &cobra.Command{
-	Use:               "start <vm name | id>+",
-	Short:             "Start virtual machine",
+	Use:               "start NAME|ID",
+	Short:             "Start a stopped Compute instance",
 	ValidArgsFunction: completeVMNames,
 	RunE: func(cmd *cobra.Command, args []string) error {
 		if len(args) < 1 {
@@ -51,23 +50,6 @@ var vmStartCmd = &cobra.Command{
 	},
 }
 
-// startVirtualMachine start a virtual machine instance Async
-func startVirtualMachine(vmName string, vmRescueProfile string) error {
-	vm, err := getVirtualMachineByNameOrID(vmName)
-	if err != nil {
-		return err
-	}
-
-	state := (string)(egoscale.VirtualMachineStopped)
-	if vm.State != state {
-		return fmt.Errorf("%q is not in a %s state, got: %s", vmName, state, vm.State)
-	}
-
-	_, err = asyncRequest(&egoscale.StartVirtualMachine{ID: vm.ID, RescueProfile: vmRescueProfile},
-		fmt.Sprintf("Starting %q ", vm.Name))
-	return err
-}
-
 func init() {
 	vmStartCmd.Flags().StringP("rescue-profile", "", "", "option rescue profile when starting VM")
 	vmCmd.AddCommand(vmStartCmd)
