@@ -8,10 +8,9 @@ import (
 	"github.com/spf13/cobra"
 )
 
-// stopCmd represents the stop command
 var vmStopCmd = &cobra.Command{
-	Use:               "stop <vm name | id>+",
-	Short:             "Stop virtual machine instance",
+	Use:               "stop NAME|ID",
+	Short:             "Stop a running Compute instance",
 	ValidArgsFunction: completeVMNames,
 	RunE: func(cmd *cobra.Command, args []string) error {
 		if len(args) < 1 {
@@ -26,7 +25,7 @@ var vmStopCmd = &cobra.Command{
 		tasks := make([]task, 0, len(args))
 		for _, v := range args {
 			if !force {
-				if !askQuestion(fmt.Sprintf("Are you sure you want to stop virtual machine %q?", v)) {
+				if !askQuestion(fmt.Sprintf("Are you sure you want to stop Compute instance %q?", v)) {
 					continue
 				}
 			}
@@ -57,23 +56,7 @@ var vmStopCmd = &cobra.Command{
 	},
 }
 
-// stopVirtualMachine stop a virtual machine instance
-func stopVirtualMachine(vmName string) error {
-	vm, err := getVirtualMachineByNameOrID(vmName)
-	if err != nil {
-		return err
-	}
-
-	state := (string)(egoscale.VirtualMachineRunning)
-	if vm.State != state {
-		return fmt.Errorf("%q is not in a %s state, got %s", vmName, state, vm.State)
-	}
-
-	_, err = asyncRequest(&egoscale.StopVirtualMachine{ID: vm.ID}, fmt.Sprintf("Stopping %q ", vm.Name))
-	return err
-}
-
 func init() {
-	vmStopCmd.Flags().BoolP("force", "f", false, "Attempt to stop virtual machine without prompting for confirmation")
+	vmStopCmd.Flags().BoolP("force", "f", false, cmdFlagForceHelp)
 	vmCmd.AddCommand(vmStopCmd)
 }
