@@ -8,8 +8,8 @@ import (
 )
 
 var vmUpdateCmd = &cobra.Command{
-	Use:               "update <vm name | id>",
-	Short:             "Update virtual machine properties",
+	Use:               "update NAME|ID",
+	Short:             "Update a Compute instance properties",
 	ValidArgsFunction: completeVMNames,
 	RunE: func(cmd *cobra.Command, args []string) error {
 		var (
@@ -50,24 +50,36 @@ var vmUpdateCmd = &cobra.Command{
 		}
 
 		if edited {
-			_, err = cs.RequestWithContext(gContext, &vmEdit)
-			if err != nil {
-				return fmt.Errorf("unable to update virtual machine: %s", err)
+			if _, err = cs.RequestWithContext(gContext, &vmEdit); err != nil {
+				return fmt.Errorf("unable to update Compute instance: %s", err)
 			}
-
-			if !gQuiet {
-				fmt.Println("Virtual machine updated successfully")
-			}
-
-			return nil
 		}
 
-		return cmd.Usage()
+		if cmd.Flags().Changed("reverse-dns") {
+			reverseDNS, err := cmd.Flags().GetString("reverse-dns")
+			if err != nil {
+				return err
+			}
+
+			if _, err = cs.RequestWithContext(gContext, &egoscale.UpdateReverseDNSForVirtualMachine{
+				ID:         vm.ID,
+				DomainName: reverseDNS,
+			}); err != nil {
+				return fmt.Errorf("unable to update Compute instance reverse DNS: %s", err)
+			}
+		}
+
+		if !gQuiet {
+			return output(showVM(vm.ID.String()))
+		}
+
+		return nil
 	},
 }
 
 func init() {
-	vmUpdateCmd.Flags().String("name", "", "display name")
+	vmUpdateCmd.Flags().String("name", "", "instance display name")
 	vmUpdateCmd.Flags().String("cloud-init-file", "", "path to a cloud-init user data file")
+	vmUpdateCmd.Flags().String("reverse-dns", "", "instance reverse DNS record")
 	vmCmd.AddCommand(vmUpdateCmd)
 }
